@@ -9,7 +9,10 @@
 #ifndef _KLIBC_ARCHCONFIG_H
 #define _KLIBC_ARCHCONFIG_H
 
-/* On i386, only half the signals are accessible using the legacy calls. */
-#define _KLIBC_USE_RT_SIG 1
+/* The i386 <asm/signal.h> is still not clean enough for this... */
+#define _KLIBC_USE_RT_SIG 0
+
+/* We have __libc_arch_init() */
+#define _KLIBC_HAS_ARCHINIT 1
 
 #endif				/* _KLIBC_ARCHCONFIG_H */
