@@ -7,6 +7,7 @@
 
 #include <klibc/extern.h>
 #include <klibc/compiler.h>
+#include <klibc/seek.h>
 #include <sys/types.h>
 #if defined(__mips__) && !defined(__mips64__)
 # include <klibc/archfcntl.h>
@@ -34,14 +35,13 @@
 # define F_SETLKW F_SETLKW64
 #endif
 
-/* This is defined here as well as in <unistd.h> since old-style code
-   would still include <fcntl.h> when using open(), and open() being
-   a varadic function changes its calling convention on some architectures. */
+/* This is defined here as well as in <unistd.h> */
 #ifndef _KLIBC_IN_OPEN_C
 __extern int open(const char *, int, ...);
 __extern int openat(int, const char *, int, ...);
 #endif
 
+__extern int creat(const char *, mode_t);
 __extern int fcntl(int, int, ...);
 
 #endif				/* _FCNTL_H */
